@@ -8,7 +8,7 @@ from muffin.plugins import BasePlugin
 from apiclient import APIClient
 
 
-__version__ = "3.0.0"
+__version__ = "3.1.0"
 __project__ = "muffin-apiclient"
 __author__ = "Kirill Klenov <horneds@gmail.com>"
 __license__ = "MIT"
@@ -23,6 +23,9 @@ class Plugin(BasePlugin):
 
     # Can be customized on setup
     name = 'apiclient'
+    root_url: t.Optional[str] = None
+    timeout: t.Optional[int] = None
+
     defaults: t.Dict = {
 
         # Root URL (https://api.github.com)
@@ -47,6 +50,11 @@ class Plugin(BasePlugin):
 
     def setup(self, app: Application, **options):
         """Setup API Client."""
+        self.cfg.update(
+            root_url=self.cfg.root_url or self.root_url,
+            timeout=self.cfg.timeout or self.timeout,
+        )
+
         super().setup(app, **options)
         self.client = APIClient(
             self.cfg.root_url, timeout=self.cfg.timeout,
